@@ -91,8 +91,8 @@ describe 'neutron::agents::dhcp' do
       before :each do
         params.merge!(:manage_service => false)
       end
-      it 'should not start/stop service' do
-        should contain_service('neutron-dhcp-service').without_ensure
+      it 'should not manage the service' do
+        should_not contain_service('neutron-dhcp-service')
       end
     end
 
